print('hello N1Ez!')

age = 17

print(f'I\'m {age} years old.')

print('This is my first python pacage.')

import example_pkg

print(example_pkg.name)